import { Navigate } from "react-router-dom";

import AuthLayout from "@/layouts/AuthLayout";
import Page404 from "@/pages/404";

import System from "./model/system";
import Project from "./model/project";
import Process from "./model/process";
import Dictionary from "./model/dictionary";

import { flatten } from "./utils";

/**
 * meta 用来扩展自定义数据数据
 * {
 *    title: 用于页面或者菜单的标题, 没有此字段, 菜单不会显示
 *    hideInMenu: 布尔值, 如果为 false, 菜单不会显示
 *    noLayout: 布尔值, 如果为 true, 将不会使用默认布局
 *    noSiderBar: 布尔值, 如果为 true, 将没有左侧菜单栏
 *    noFooter: 布尔值, 如果为 true, 将没有底部 footer
 *    target: 字符串, 如果为 _blank, 将在新窗口打开
 *    permission: 对应服务器端权限名称
 * }
 */
export const routes = [
  {
    index: true,
    element: <Navigate to="/project" replace={true} />,
  },
  Project, //项目管理
  Process, // 流程管理
  Dictionary, //字典管理
  System, //系统管理
];

export function getAllRoutes(routes) {
  return [
    {
      path: "/",
      element: <AuthLayout />,
      children: [
        {
          path: "*",
          element: <Page404 />,
        },
        ...(routes || []),
      ],
    },
    {
      path: "*",
      element: <Page404 />,
    },
  ];
}

// 展平路由
export const flattenRoutes = flatten(getAllRoutes(routes));